@@ -208,3 +208,24 @@ class TestUtils:
             msg.append((" detected, please refer to file: "
                         "'%s' for more details.") % BG_ERR_FILE)
             self.error(''.join(msg))
+
+    @property
+    def datadir(self):
+        """
+        Returns the path to the directory that contains test data files
+
+        For VT tests, this always returns None. The reason is that
+        individual VT tests do not map 1:1 to a file and do not provide
+        the concept of a datadir.
+        """
+        return None
+
+    @property
+    def filename(self):
+        """
+        Returns the name of the file (path) that holds the current test
+
+        For VT tests, this always returns None. The reason is that
+        individual VT tests do not map 1:1 to a file.
+        """
+        return None
